@@ -1,9 +1,9 @@
 /* Test of test whether an UTF-16 string is entirely lower case.
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -74,5 +74,5 @@ main ()
   test_ascii (u16_is_lowercase);
   test_nonascii (u16_is_lowercase);
 
-  return 0;
+  return test_exit_status;
 }
