@@ -1,5 +1,5 @@
 /* Test of test whether case matters for an UTF-8 string.
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -32,5 +32,5 @@ main ()
 {
   test_ascii (u8_is_cased);
 
-  return 0;
+  return test_exit_status;
 }
