@@ -1,5 +1,5 @@
 /* Test of test whether an UTF-8 string is entirely upper case.
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -74,5 +74,5 @@ main ()
   test_ascii (u8_is_uppercase);
   test_nonascii (u8_is_uppercase);
 
-  return 0;
+  return test_exit_status;
 }
