@@ -1,10 +1,10 @@
 /* Test of locale dependent, case and normalization insensitive comparison of
    strings.
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -41,5 +41,5 @@ main ()
      on ASCII strings should behave like strcasecmp.  */
   test_ascii (ulc_casecoll, UNINORM_NFC);
 
-  return 0;
+  return test_exit_status;
 }
