@@ -1,5 +1,5 @@
 /* Test the Unicode character type functions.
-   Copyright (C) 2007-2009 Free Software Foundation, Inc.
+   Copyright (C) 2007-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,5 +35,5 @@ main ()
   ASSERT (uc_is_general_category ('7', ct));
   ASSERT (!uc_is_general_category (0x00B2, ct));
 
-  return 0;
+  return test_exit_status;
 }
