@@ -1,5 +1,5 @@
 /* Previous grapheme cluster test.
-   Copyright (C) 2010-2022 Free Software Foundation, Inc.
+   Copyright (C) 2010-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU Lesser General Public License as published
@@ -39,11 +39,12 @@ test_u8_grapheme_prev (const char *input, size_t n, size_t len)
       if (prev == NULL)
         fputs ("u8_grapheme_prev returned NULL", stderr);
       else
-        fprintf (stderr, "u8_grapheme_prev skipped %zu bytes", end - prev);
+        fprintf (stderr, "u8_grapheme_prev skipped %tu bytes", end - prev);
       fprintf (stderr, ", expected %zu:\n", len);
       for (i = 0; i < n; i++)
         fprintf (stderr, " %02x", s[i]);
       putc ('\n', stderr);
+      fflush (stderr);
       abort ();
     }
 }
@@ -76,5 +77,5 @@ main (void)
   test_u8_grapheme_prev ("e"ACUTE"x", 4, 1);
   test_u8_grapheme_prev ("e"ACUTE "e"ACUTE, 6, 3);
 
-  return 0;
+  return test_exit_status;
 }
