@@ -1,9 +1,9 @@
 /* Grapheme cluster breaks test.
-   Copyright (C) 2009-2018 Free Software Foundation, Inc.
+   Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -64,7 +64,7 @@ main ()
 
           fprintf (stderr, "   input:");
           for (j = 0; j < LENGTH; j++)
-            fprintf (stderr, " %02x", (unsigned char) s[j]);
+            fprintf (stderr, " %02X", (unsigned char) s[j]);
           putc ('\n', stderr);
 
           fprintf (stderr, "expected:");
@@ -77,10 +77,11 @@ main ()
             fprintf (stderr, "  %d", p[j]);
           putc ('\n', stderr);
 
+          fflush (stderr);
           abort ();
         }
   }
 #endif
 
-  return 0;
+  return test_exit_status;
 }
