@@ -1,5 +1,5 @@
 /* Test of normalization insensitive comparison of UTF-16 strings.
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -112,5 +112,5 @@ main ()
   test_ascii (u16_normcmp, UNINORM_NFD);
   test_nonascii (u16_normcmp);
 
-  return 0;
+  return test_exit_status;
 }
