@@ -1,9 +1,9 @@
 /* Test of u16_v[a]s[n]printf() function.
-   Copyright (C) 2007, 2009-2016 Free Software Foundation, Inc.
+   Copyright (C) 2007, 2009-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -12,7 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
 
 /* Written by Bruno Haible <bruno@clisp.org>, 2007.  */
 
@@ -83,6 +83,24 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
       ASSERT (u16_strcmp (result, expected) == 0);
       free (result);
     }
+    { /* Width given as argument.  */
+      uint16_t *result =
+        my_xasprintf ("%*U %d", 10, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { ' ', ' ', ' ', ' ', ' ', 'H', 'e', 'l', 'l', 'o', ' ', '3', '3', 0 };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
+    { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+      uint16_t *result =
+        my_xasprintf ("%*U %d", -10, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { 'H', 'e', 'l', 'l', 'o', ' ', ' ', ' ', ' ', ' ', ' ', '3', '3', 0 };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
     { /* FLAG_LEFT.  */
       uint16_t *result =
         my_xasprintf ("%-10U %d", unicode_string, 33, 44, 55);
@@ -102,6 +120,32 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
       free (result);
     }
   }
+  { /* Width with a non-ASCII argument.  */
+    static const uint8_t unicode_string[] = /* hétérogénéité */
+      "h\303\251t\303\251rog\303\251n\303\251it\303\251";
+    uint16_t *result =
+      my_xasprintf ("%20U %d", unicode_string, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'h', 0x00e9, 't',
+        0x00e9, 'r', 'o', 'g', 0x00e9, 'n', 0x00e9, 'i', 't', 0x00e9,
+        ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+  { /* Width with a non-BMP argument.  */
+    static const uint8_t unicode_string[] = "\360\237\220\203"; /* 🐃 */
+    uint16_t *result =
+      my_xasprintf ("%10U %d", unicode_string, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 0xd83d,
+        0xdc03, ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
 
   {
     static const uint16_t unicode_string[] = { 'H', 'e', 'l', 'l', 'o', 0 };
@@ -123,6 +167,24 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
       ASSERT (u16_strcmp (result, expected) == 0);
       free (result);
     }
+    { /* Width given as argument.  */
+      uint16_t *result =
+        my_xasprintf ("%*lU %d", 10, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { ' ', ' ', ' ', ' ', ' ', 'H', 'e', 'l', 'l', 'o', ' ', '3', '3', 0 };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
+    { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+      uint16_t *result =
+        my_xasprintf ("%*lU %d", -10, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { 'H', 'e', 'l', 'l', 'o', ' ', ' ', ' ', ' ', ' ', ' ', '3', '3', 0 };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
     { /* FLAG_LEFT.  */
       uint16_t *result =
         my_xasprintf ("%-10lU %d", unicode_string, 33, 44, 55);
@@ -142,6 +204,34 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
       free (result);
     }
   }
+  { /* Width with a non-ASCII argument.  */
+    static const uint16_t unicode_string[] = /* hétérogénéité */
+      { 'h', 0x00e9, 't', 0x00e9, 'r', 'o', 'g', 0x00e9, 'n', 0x00e9,
+        'i', 't', 0x00e9, 0
+      };
+    uint16_t *result =
+      my_xasprintf ("%20lU %d", unicode_string, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'h', 0x00e9, 't',
+        0x00e9, 'r', 'o', 'g', 0x00e9, 'n', 0x00e9, 'i', 't', 0x00e9,
+        ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+  { /* Width with a non-BMP argument.  */
+    static const uint16_t unicode_string[] = { 0xd83d, 0xdc03, 0 }; /* 🐃 */
+    uint16_t *result =
+      my_xasprintf ("%10lU %d", unicode_string, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 0xd83d,
+        0xdc03, ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
 
   {
     static const uint32_t unicode_string[] = { 'H', 'e', 'l', 'l', 'o', 0 };
@@ -163,6 +253,24 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
       ASSERT (u16_strcmp (result, expected) == 0);
       free (result);
     }
+    { /* Width given as argument.  */
+      uint16_t *result =
+        my_xasprintf ("%*llU %d", 10, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { ' ', ' ', ' ', ' ', ' ', 'H', 'e', 'l', 'l', 'o', ' ', '3', '3', 0 };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
+    { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+      uint16_t *result =
+        my_xasprintf ("%*llU %d", -10, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { 'H', 'e', 'l', 'l', 'o', ' ', ' ', ' ', ' ', ' ', ' ', '3', '3', 0 };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
     { /* FLAG_LEFT.  */
       uint16_t *result =
         my_xasprintf ("%-10llU %d", unicode_string, 33, 44, 55);
@@ -182,6 +290,34 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
       free (result);
     }
   }
+  { /* Width with a non-ASCII argument.  */
+    static const uint32_t unicode_string[] = /* hétérogénéité */
+      { 'h', 0x00e9, 't', 0x00e9, 'r', 'o', 'g', 0x00e9, 'n', 0x00e9,
+        'i', 't', 0x00e9, 0
+      };
+    uint16_t *result =
+      my_xasprintf ("%20llU %d", unicode_string, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', ' ', ' ', ' ', ' ', ' ', 'h', 0x00e9, 't',
+        0x00e9, 'r', 'o', 'g', 0x00e9, 'n', 0x00e9, 'i', 't', 0x00e9,
+        ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+  { /* Width with a non-BMP argument.  */
+    static const uint32_t unicode_string[] = { 0x1f403, 0 }; /* 🐃 */
+    uint16_t *result =
+      my_xasprintf ("%10llU %d", unicode_string, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', ' ', 0xd83d,
+        0xdc03, ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
 
   /* Test the support of the 's' conversion specifier for strings.  */
 
@@ -211,6 +347,32 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
     free (result);
   }
 
+  { /* Width given as argument.  */
+    uint16_t *result =
+      my_xasprintf ("Mr. %*s %d", 20, "Ronald Reagan", 33, 44, 55);
+    static const uint16_t expected[] =
+      { 'M', 'r', '.', ' ', ' ', ' ', ' ', ' ', ' ', ' ',
+        ' ', 'R', 'o', 'n', 'a', 'l', 'd', ' ', 'R', 'e',
+        'a', 'g', 'a', 'n', ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
+  { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+    uint16_t *result =
+      my_xasprintf ("Mr. %*s %d", -20, "Ronald Reagan", 33, 44, 55);
+    static const uint16_t expected[] =
+      { 'M', 'r', '.', ' ', 'R', 'o', 'n', 'a', 'l', 'd',
+        ' ', 'R', 'e', 'a', 'g', 'a', 'n', ' ', ' ', ' ',
+        ' ', ' ', ' ', ' ', ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
   { /* FLAG_LEFT.  */
     uint16_t *result =
       my_xasprintf ("Mr. %-20s %d", "Ronald Reagan", 33, 44, 55);
@@ -278,6 +440,44 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
     free (result);
   }
 
+  { /* Width given as argument.  */
+    uint16_t *result =
+      my_xasprintf ("%*a %d", 10, 1.75, 33, 44, 55);
+    static const uint16_t expected1[] =
+      { ' ', ' ', '0', 'x', '1', '.', 'c', 'p', '+', '0', ' ', '3', '3', 0 };
+    static const uint16_t expected2[] =
+      { ' ', ' ', '0', 'x', '3', '.', '8', 'p', '-', '1', ' ', '3', '3', 0 };
+    static const uint16_t expected3[] =
+      { ' ', ' ', ' ', ' ', '0', 'x', '7', 'p', '-', '2', ' ', '3', '3', 0 };
+    static const uint16_t expected4[] =
+      { ' ', ' ', ' ', ' ', '0', 'x', 'e', 'p', '-', '3', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected1) == 0
+            || u16_strcmp (result, expected2) == 0
+            || u16_strcmp (result, expected3) == 0
+            || u16_strcmp (result, expected4) == 0);
+    free (result);
+  }
+
+  { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+    uint16_t *result =
+      my_xasprintf ("%*a %d", -10, 1.75, 33, 44, 55);
+    static const uint16_t expected1[] =
+      { '0', 'x', '1', '.', 'c', 'p', '+', '0', ' ', ' ', ' ', '3', '3', 0 };
+    static const uint16_t expected2[] =
+      { '0', 'x', '3', '.', '8', 'p', '-', '1', ' ', ' ', ' ', '3', '3', 0 };
+    static const uint16_t expected3[] =
+      { '0', 'x', '7', 'p', '-', '2', ' ', ' ', ' ', ' ', ' ', '3', '3', 0 };
+    static const uint16_t expected4[] =
+      { '0', 'x', 'e', 'p', '-', '3', ' ', ' ', ' ', ' ', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected1) == 0
+            || u16_strcmp (result, expected2) == 0
+            || u16_strcmp (result, expected3) == 0
+            || u16_strcmp (result, expected4) == 0);
+    free (result);
+  }
+
   { /* Small precision.  */
     uint16_t *result =
       my_xasprintf ("%.10a %d", 1.75, 33, 44, 55);
@@ -402,6 +602,44 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
     free (result);
   }
 
+  { /* Width given as argument.  */
+    uint16_t *result =
+      my_xasprintf ("%*La %d", 10, 1.75L, 33, 44, 55);
+    static const uint16_t expected1[] =
+      { ' ', ' ', '0', 'x', '1', '.', 'c', 'p', '+', '0', ' ', '3', '3', 0 };
+    static const uint16_t expected2[] =
+      { ' ', ' ', '0', 'x', '3', '.', '8', 'p', '-', '1', ' ', '3', '3', 0 };
+    static const uint16_t expected3[] =
+      { ' ', ' ', ' ', ' ', '0', 'x', '7', 'p', '-', '2', ' ', '3', '3', 0 };
+    static const uint16_t expected4[] =
+      { ' ', ' ', ' ', ' ', '0', 'x', 'e', 'p', '-', '3', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected1) == 0
+            || u16_strcmp (result, expected2) == 0
+            || u16_strcmp (result, expected3) == 0
+            || u16_strcmp (result, expected4) == 0);
+    free (result);
+  }
+
+  { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+    uint16_t *result =
+      my_xasprintf ("%*La %d", -10, 1.75L, 33, 44, 55);
+    static const uint16_t expected1[] =
+      { '0', 'x', '1', '.', 'c', 'p', '+', '0', ' ', ' ', ' ', '3', '3', 0 };
+    static const uint16_t expected2[] =
+      { '0', 'x', '3', '.', '8', 'p', '-', '1', ' ', ' ', ' ', '3', '3', 0 };
+    static const uint16_t expected3[] =
+      { '0', 'x', '7', 'p', '-', '2', ' ', ' ', ' ', ' ', ' ', '3', '3', 0 };
+    static const uint16_t expected4[] =
+      { '0', 'x', 'e', 'p', '-', '3', ' ', ' ', ' ', ' ', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected1) == 0
+            || u16_strcmp (result, expected2) == 0
+            || u16_strcmp (result, expected3) == 0
+            || u16_strcmp (result, expected4) == 0);
+    free (result);
+  }
+
   { /* Small precision.  */
     uint16_t *result =
       my_xasprintf ("%.10La %d", 1.75L, 33, 44, 55);
@@ -502,6 +740,26 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
     free (result);
   }
 
+  { /* Width given as argument.  */
+    uint16_t *result =
+      my_xasprintf ("%*f %d", 10, 1.75, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', '1', '.', '7', '5', '0', '0', '0', '0', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
+  { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+    uint16_t *result =
+      my_xasprintf ("%*f %d", -10, 1.75, 33, 44, 55);
+    static const uint16_t expected[] =
+      { '1', '.', '7', '5', '0', '0', '0', '0', ' ', ' ', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
   { /* Precision.  */
     uint16_t *result =
       my_xasprintf ("%.f %d", 1234.0, 33, 44, 55);
@@ -532,6 +790,26 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
     free (result);
   }
 
+  { /* Width given as argument.  */
+    uint16_t *result =
+      my_xasprintf ("%*Lf %d", 10, 1.75L, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', '1', '.', '7', '5', '0', '0', '0', '0', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
+  { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+    uint16_t *result =
+      my_xasprintf ("%*Lf %d", -10, 1.75L, 33, 44, 55);
+    static const uint16_t expected[] =
+      { '1', '.', '7', '5', '0', '0', '0', '0', ' ', ' ', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
   { /* Precision.  */
     uint16_t *result =
       my_xasprintf ("%.Lf %d", 1234.0L, 33, 44, 55);
@@ -620,6 +898,40 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
     free (result);
   }
 
+  { /* Width given as argument.  */
+    uint16_t *result =
+      my_xasprintf ("%*e %d", 15, 1.75, 33, 44, 55);
+    static const uint16_t expected1[] =
+      { ' ', ' ', ' ', '1', '.', '7', '5', '0', '0', '0',
+        '0', 'e', '+', '0', '0', ' ', '3', '3', 0
+      };
+    static const uint16_t expected2[] =
+      { ' ', ' ', '1', '.', '7', '5', '0', '0', '0', '0',
+        'e', '+', '0', '0', '0', ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected1) == 0
+            || u16_strcmp (result, expected2) == 0);
+    free (result);
+  }
+
+  { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+    uint16_t *result =
+      my_xasprintf ("%*e %d", -15, 1.75, 33, 44, 55);
+    static const uint16_t expected1[] =
+      { '1', '.', '7', '5', '0', '0', '0', '0', 'e', '+',
+        '0', '0', ' ', ' ', ' ', ' ', '3', '3', 0
+      };
+    static const uint16_t expected2[] =
+      { '1', '.', '7', '5', '0', '0', '0', '0', 'e', '+',
+        '0', '0', '0', ' ', ' ', ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected1) == 0
+            || u16_strcmp (result, expected2) == 0);
+    free (result);
+  }
+
   { /* Precision.  */
     uint16_t *result =
       my_xasprintf ("%.e %d", 1234.0, 33, 44, 55);
@@ -657,6 +969,30 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
     free (result);
   }
 
+  { /* Width given as argument.  */
+    uint16_t *result =
+      my_xasprintf ("%*Le %d", 15, 1.75L, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', ' ', '1', '.', '7', '5', '0', '0', '0',
+        '0', 'e', '+', '0', '0', ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
+  { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+    uint16_t *result =
+      my_xasprintf ("%*Le %d", -15, 1.75L, 33, 44, 55);
+    static const uint16_t expected[] =
+      { '1', '.', '7', '5', '0', '0', '0', '0', 'e', '+',
+        '0', '0', ' ', ' ', ' ', ' ', '3', '3', 0
+      };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
   { /* Precision.  */
     uint16_t *result =
       my_xasprintf ("%.Le %d", 1234.0L, 33, 44, 55);
@@ -689,6 +1025,26 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
     free (result);
   }
 
+  { /* Width given as argument.  */
+    uint16_t *result =
+      my_xasprintf ("%*g %d", 10, 1.75, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', ' ', ' ', ' ', ' ', '1', '.', '7', '5', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
+  { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+    uint16_t *result =
+      my_xasprintf ("%*g %d", -10, 1.75, 33, 44, 55);
+    static const uint16_t expected[] =
+      { '1', '.', '7', '5', ' ', ' ', ' ', ' ', ' ', ' ', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
   { /* Precision.  */
     uint16_t *result =
       my_xasprintf ("%.g %d", 1234.0, 33, 44, 55);
@@ -722,6 +1078,26 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
     free (result);
   }
 
+  { /* Width given as argument.  */
+    uint16_t *result =
+      my_xasprintf ("%*Lg %d", 10, 1.75L, 33, 44, 55);
+    static const uint16_t expected[] =
+      { ' ', ' ', ' ', ' ', ' ', ' ', '1', '.', '7', '5', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
+  { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+    uint16_t *result =
+      my_xasprintf ("%*Lg %d", -10, 1.75L, 33, 44, 55);
+    static const uint16_t expected[] =
+      { '1', '.', '7', '5', ' ', ' ', ' ', ' ', ' ', ' ', ' ', '3', '3', 0 };
+    ASSERT (result != NULL);
+    ASSERT (u16_strcmp (result, expected) == 0);
+    free (result);
+  }
+
   { /* Precision.  */
     uint16_t *result =
       my_xasprintf ("%.Lg %d", 1234.0L, 33, 44, 55);
@@ -738,12 +1114,16 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
     int count = -1;
     uint16_t *result =
       my_xasprintf ("%d %n", 123, &count, 33, 44, 55);
+#if NEED_PRINTF_WITH_N_DIRECTIVE
     static const uint16_t expected[] =
       { '1', '2', '3', ' ', 0 };
     ASSERT (result != NULL);
     ASSERT (u16_strcmp (result, expected) == 0);
     ASSERT (count == 4);
     free (result);
+#else
+    ASSERT (result == NULL);
+#endif
   }
 
   /* Test the support of the POSIX/XSI format strings with positions.  */
@@ -795,6 +1175,30 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
       ASSERT (u16_strcmp (result, expected) == 0);
       free (result);
     }
+    { /* Width given as argument.  */
+      uint16_t *result =
+        my_xasprintf ("%*U %d", 20, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { ' ', ' ', ' ', ' ', 'R', 'a', 'f', 'a', 0x0142, ' ',
+          'M', 'a', 's', 'z', 'k', 'o', 'w', 's', 'k', 'i',
+          ' ', '3', '3', 0
+        };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
+    { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+      uint16_t *result =
+        my_xasprintf ("%*U %d", -20, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { 'R', 'a', 'f', 'a', 0x0142, ' ', 'M', 'a', 's', 'z',
+          'k', 'o', 'w', 's', 'k', 'i', ' ', ' ', ' ', ' ',
+          ' ', '3', '3', 0
+        };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
     { /* FLAG_LEFT.  */
       uint16_t *result =
         my_xasprintf ("%-20U %d", unicode_string, 33, 44, 55);
@@ -850,6 +1254,30 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
       ASSERT (u16_strcmp (result, expected) == 0);
       free (result);
     }
+    { /* Width given as argument.  */
+      uint16_t *result =
+        my_xasprintf ("%*lU %d", 20, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { ' ', ' ', ' ', ' ', 'R', 'a', 'f', 'a', 0x0142, ' ',
+          'M', 'a', 's', 'z', 'k', 'o', 'w', 's', 'k', 'i',
+          ' ', '3', '3', 0
+        };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
+    { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+      uint16_t *result =
+        my_xasprintf ("%*lU %d", -20, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { 'R', 'a', 'f', 'a', 0x0142, ' ', 'M', 'a', 's', 'z',
+          'k', 'o', 'w', 's', 'k', 'i', ' ', ' ', ' ', ' ',
+          ' ', '3', '3', 0
+        };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
     { /* FLAG_LEFT.  */
       uint16_t *result =
         my_xasprintf ("%-20lU %d", unicode_string, 33, 44, 55);
@@ -905,6 +1333,30 @@ test_xfunction (uint16_t * (*my_xasprintf) (const char *, ...))
       ASSERT (u16_strcmp (result, expected) == 0);
       free (result);
     }
+    { /* Width given as argument.  */
+      uint16_t *result =
+        my_xasprintf ("%*llU %d", 20, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { ' ', ' ', ' ', ' ', 'R', 'a', 'f', 'a', 0x0142, ' ',
+          'M', 'a', 's', 'z', 'k', 'o', 'w', 's', 'k', 'i',
+          ' ', '3', '3', 0
+        };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
+    { /* Negative width given as argument (cf. FLAG_LEFT below).  */
+      uint16_t *result =
+        my_xasprintf ("%*llU %d", -20, unicode_string, 33, 44, 55);
+      static const uint16_t expected[] =
+        { 'R', 'a', 'f', 'a', 0x0142, ' ', 'M', 'a', 's', 'z',
+          'k', 'o', 'w', 's', 'k', 'i', ' ', ' ', ' ', ' ',
+          ' ', '3', '3', 0
+        };
+      ASSERT (result != NULL);
+      ASSERT (u16_strcmp (result, expected) == 0);
+      free (result);
+    }
     { /* FLAG_LEFT.  */
       uint16_t *result =
         my_xasprintf ("%-20llU %d", unicode_string, 33, 44, 55);
