@@ -1,5 +1,5 @@
 /* Test of u32_asnprintf() function.
-   Copyright (C) 2007-2022 Free Software Foundation, Inc.
+   Copyright (C) 2007-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -42,5 +42,5 @@ int
 main (int argc, char *argv[])
 {
   test_asnprintf ();
-  return 0;
+  return test_exit_status;
 }
