@@ -1,5 +1,5 @@
 /* Test of ulc_vasnprintf() function.
-   Copyright (C) 2007-2022 Free Software Foundation, Inc.
+   Copyright (C) 2007-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 
 #include "unistdio.h"
 
+#include <errno.h>
 #include <stdarg.h>
 #include <stddef.h>
 #include <stdint.h>
@@ -69,5 +70,5 @@ int
 main (int argc, char *argv[])
 {
   test_vasnprintf ();
-  return 0;
+  return test_exit_status;
 }
