@@ -1,5 +1,5 @@
 /* Test of ulc_vasnprintf() function in an ISO-8859-1 locale.
-   Copyright (C) 2007-2022 Free Software Foundation, Inc.
+   Copyright (C) 2007-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -76,6 +76,16 @@ test_function (char * (*my_asnprintf) (char *, size_t *, const char *, ...))
       free (result);
     }
   }
+  { /* Width with a non-BMP argument.  */
+    static const uint8_t unicode_string[] = "\360\237\220\203"; /* 🐃 */
+    size_t length;
+    char *result =
+      my_asnprintf (NULL, &length, "%10U %d", unicode_string, 33, 44, 55);
+    ASSERT (result != NULL);
+    ASSERT (strcmp (result, "         ? 33") == 0);
+    ASSERT (length == strlen (result));
+    free (result);
+  }
 
   {
     static const uint16_t unicode_string[] = /* Rafał Maszkowski */
@@ -124,6 +134,16 @@ test_function (char * (*my_asnprintf) (char *, size_t *, const char *, ...))
       free (result);
     }
   }
+  { /* Width with a non-BMP argument.  */
+    static const uint16_t unicode_string[] = { 0xd83d, 0xdc03, 0 }; /* 🐃 */
+    size_t length;
+    char *result =
+      my_asnprintf (NULL, &length, "%10lU %d", unicode_string, 33, 44, 55);
+    ASSERT (result != NULL);
+    ASSERT (strcmp (result, "         ? 33") == 0);
+    ASSERT (length == strlen (result));
+    free (result);
+  }
 
   {
     static const uint32_t unicode_string[] = /* Rafał Maszkowski */
@@ -172,6 +192,16 @@ test_function (char * (*my_asnprintf) (char *, size_t *, const char *, ...))
       free (result);
     }
   }
+  { /* Width with a non-BMP argument.  */
+    static const uint32_t unicode_string[] = { 0x1f403, 0 }; /* 🐃 */
+    size_t length;
+    char *result =
+      my_asnprintf (NULL, &length, "%10llU %d", unicode_string, 33, 44, 55);
+    ASSERT (result != NULL);
+    ASSERT (strcmp (result, "         ? 33") == 0);
+    ASSERT (length == strlen (result));
+    free (result);
+  }
 
   /* Test the support of the 's' conversion specifier for strings.  */
 
@@ -214,6 +244,50 @@ test_function (char * (*my_asnprintf) (char *, size_t *, const char *, ...))
       free (result);
     }
   }
+
+  /* Test the support of the 'ls' conversion specifier for wide strings.  */
+
+  {
+    const char *locale_string = "h\351t\351rog\351n\351it\351"; /* hétérogénéité */
+    wchar_t wide_string[20];
+    ASSERT (mbstowcs (wide_string, locale_string, SIZEOF (wide_string)) == 13);
+    {
+      size_t length;
+      char *result =
+        my_asnprintf (NULL, &length, "%ls %d", wide_string, 33, 44, 55);
+      ASSERT (result != NULL);
+      ASSERT (strcmp (result, "h\351t\351rog\351n\351it\351 33") == 0);
+      ASSERT (length == strlen (result));
+      free (result);
+    }
+    { /* Width.  */
+      size_t length;
+      char *result =
+        my_asnprintf (NULL, &length, "%20ls %d", wide_string, 33, 44, 55);
+      ASSERT (result != NULL);
+      ASSERT (strcmp (result, "       h\351t\351rog\351n\351it\351 33") == 0);
+      ASSERT (length == strlen (result));
+      free (result);
+    }
+    { /* FLAG_LEFT.  */
+      size_t length;
+      char *result =
+        my_asnprintf (NULL, &length, "%-20ls %d", wide_string, 33, 44, 55);
+      ASSERT (result != NULL);
+      ASSERT (strcmp (result, "h\351t\351rog\351n\351it\351        33") == 0);
+      ASSERT (length == strlen (result));
+      free (result);
+    }
+    { /* FLAG_ZERO: no effect.  */
+      size_t length;
+      char *result =
+        my_asnprintf (NULL, &length, "%020ls %d", wide_string, 33, 44, 55);
+      ASSERT (result != NULL);
+      ASSERT (strcmp (result, "       h\351t\351rog\351n\351it\351 33") == 0);
+      ASSERT (length == strlen (result));
+      free (result);
+    }
+  }
 }
 
 static char *
@@ -242,5 +316,5 @@ main (int argc, char *argv[])
     return 1;
 
   test_vasnprintf ();
-  return 0;
+  return test_exit_status;
 }
