@@ -1,5 +1,5 @@
 /* Test of ulc_vsnprintf() function.
-   Copyright (C) 2007-2022 Free Software Foundation, Inc.
+   Copyright (C) 2007-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -57,5 +57,5 @@ main (int argc, char *argv[])
 {
   test_vsnprintf ();
 
-  return 0;
+  return test_exit_status;
 }
