@@ -1,5 +1,5 @@
 /* Test of u16_check() function.
-   Copyright (C) 2010-2022 Free Software Foundation, Inc.
+   Copyright (C) 2010-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -62,5 +62,5 @@ main ()
     ASSERT (u16_check (input, SIZEOF (input)) == input + 2);
   }
 
-  return 0;
+  return test_exit_status;
 }
