@@ -1,5 +1,5 @@
 /* Test of u16_strlen() function.
-   Copyright (C) 2010-2022 Free Software Foundation, Inc.
+   Copyright (C) 2010-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -53,5 +53,5 @@ main ()
     ASSERT (u16_strlen (input) == SIZEOF (input) - 1);
   }
 
-  return 0;
+  return test_exit_status;
 }
