@@ -1,5 +1,5 @@
 /* Test of u16_strtok() function.
-   Copyright (C) 2015-2022 Free Software Foundation, Inc.
+   Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -33,5 +33,5 @@ main (void)
 {
   test_u_strtok ();
 
-  return 0;
+  return test_exit_status;
 }
