@@ -1,5 +1,5 @@
 /* Test of u32_mbtouc() function.
-   Copyright (C) 2010-2022 Free Software Foundation, Inc.
+   Copyright (C) 2010-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,5 +29,5 @@ main ()
 {
   test_function (u32_mbtouc);
 
-  return 0;
+  return test_exit_status;
 }
