@@ -1,9 +1,9 @@
 /* Test of u32_strtok() function.
-   Copyright (C) 2015-2022 Free Software Foundation, Inc.
+   Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -33,5 +33,5 @@ main (void)
 {
   test_u_strtok ();
 
-  return 0;
+  return test_exit_status;
 }
