@@ -1,9 +1,9 @@
 /* Test of u8_strncmp() function.
-   Copyright (C) 2010-2018 Free Software Foundation, Inc.
+   Copyright (C) 2010-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 3 of the License, or
+   the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -49,5 +49,5 @@ main ()
     ASSERT (U_STRNCMP (input2, input1, 1000000) < 0);
   }
 
-  return 0;
+  return test_exit_status;
 }
