@@ -1,5 +1,5 @@
 /* Test of word breaks in strings.
-   Copyright (C) 2009-2022 Free Software Foundation, Inc.
+   Copyright (C) 2009-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -58,5 +58,5 @@ main ()
   }
 #endif
 
-  return 0;
+  return test_exit_status;
 }
