@@ -1,5 +1,5 @@
 /* Test of u16_strwidth() function.
-   Copyright (C) 2007-2022 Free Software Foundation, Inc.
+   Copyright (C) 2007-2024 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -54,5 +54,5 @@ main ()
     ASSERT (u16_strwidth (input, "GB2312") == 6);
   }
 
-  return 0;
+  return test_exit_status;
 }
